unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, StdCtrls, wcrypt2;

type
  TMainForm = class(TForm)
    MainMenu1: TMainMenu;
    FileItem: TMenuItem;
    OpenItem: TMenuItem;
    EncryptItem: TMenuItem;
    DecryptItem: TMenuItem;
    SaveItem: TMenuItem;
    ExitItem: TMenuItem;
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    CloseItem: TMenuItem;
    procedure OpenItemClick(Sender: TObject);
    procedure ExitItemClick(Sender: TObject);
    procedure EncryptItemClick(Sender: TObject);
    procedure SaveItemClick(Sender: TObject);
    procedure CloseItemClick(Sender: TObject);
    procedure GetPassword;
    procedure EncryptData;
    procedure DecryptData;
    procedure DecryptItemClick(Sender: TObject);

  private
    { Private declarations }
    plaintext, ciphertext: string;
  public
    { Public declarations }
    hProv: HCRYPTPROV;
    key: HCRYPTKEY;
    encrypt: boolean;
  end;

var
  MainForm: TMainForm;

implementation

uses Passwd;

{$R *.DFM}

type algInfo = record
     algID: ALG_ID;
     dwBits: DWORD;
     dwNameLen: DWORD;
     szName: array[0..100] of char;
     end;

procedure TMainForm.OpenItemClick(Sender: TObject);
begin
OpenDialog1.Title := ' ';
if OpenDialog1.Execute then
   begin
   plaintext := OpenDialog1.FileName;
   EncryptItem.Enabled := true;
   CloseItem.Enabled := true;
   end;
end;

procedure TMainForm.ExitItemClick(Sender: TObject);
begin
Close;
end;

procedure TMainForm.GetPassword;
begin
if not CryptAcquireContext(@hProv, nil, nil, PROV_RSA_FULL, CRYPT_VERIFYCONTEXT) then
   begin
   MessageDlg('Error m1', mtError, [mbOK], 0);
   exit;
   end;
PasswordForm.Show;
end;

procedure TMainForm.EncryptItemClick(Sender: TObject);
begin
encrypt := true;
GetPassword;
end;

procedure TMainForm.EncryptData;
var i: integer;
    l: DWORD;
    data: PByte;
    inFile, outFile: file;
begin
SaveDialog1.Title := '   ?';
if SaveDialog1.Execute then
   begin
   ciphertext := SaveDialog1.FileName;
   AssignFile(inFile, plaintext);
   AssignFile(outFile, ciphertext);
   reset(inFile, 1);
   rewrite(outFile, 1);
   GetMem(data, 512);
   while not eof(inFile) do
         begin
         BlockRead(inFile, data^, 512, l);
         if not CryptEncrypt(key, 0, eof(inFile), 0,
            data, @l, l) then
            begin
            MessageDlg('Error m2', mtError, [mbOK], 0);
            exit;
            end;
         BlockWrite(outFile, data^, l);
         end;
   FreeMem(data, 512);
   CloseFile(inFile);
   CloseFile(outFile);
   plaintext := '';
   ciphertext := '';
   EncryptItem.Enabled := false;
   end;
if not CryptReleaseContext(hProv, 0) then
   begin
   MessageDlg('Error 3m', mtError, [mbOK], 0);
   end;
end;

procedure TMainForm.DecryptData;
var i: integer;
    l: DWORD;
    err: string;
    data: PByte;
    inFile, outFile: file;
begin
SaveDialog1.Title := '   ?';
if SaveDialog1.Execute then
   begin
   plaintext := SaveDialog1.FileName;
   AssignFile(inFile, ciphertext);
   AssignFile(outFile, plaintext);
   reset(inFile, 1);
   rewrite(outFile, 1);
   GetMem(data, 512);
   while not eof(inFile) do
         begin
         BlockRead(inFile, data^, 512, l);
         if not CryptDecrypt(key, 0, eof(inFile), 0,
            data, @l) then
            begin
            MessageDlg('Error m4', mtError, [mbOK], 0);
            exit;
            end;
         BlockWrite(outFile, data^, l);
         end;
   FreeMem(data, 512);
   CloseFile(inFile);
   CloseFile(outFile);
   end;
end;

procedure TMainForm.SaveItemClick(Sender: TObject);
begin
SaveDialog1.Title := '  ';
if SaveDialog1.Execute then
   begin
   plaintext := SaveDialog1.FileName;
   EncryptItem.Enabled := true;
   end;
end;

procedure TMainForm.CloseItemClick(Sender: TObject);
begin
EncryptItem.Enabled := false;
plaintext := '';
ciphertext := '';
end;

procedure TMainForm.DecryptItemClick(Sender: TObject);
begin
OpenDialog1.Title := '   ';
if OpenDialog1.Execute then
   begin
   ciphertext := OpenDialog1.FileName;
   encrypt := false;
   GetPassword;
   end;
end;



end.
